.. _Cookiecutter: https://github.com/cookiecutter/cookiecutter
.. _Grove Code Templates: https://github.com/hashicorp-forge/grove/tree/main/templates/code

Development
===========

.. note::
    Please also see the :doc:`Internals <internals>` and :doc:`Style <style>` sections
    of this documentation for more information about Grove internals and recommended
    code style.

In order to enable the rapid development of plugins to support new backends, as well as
the creation of new connectors to support new log sources, Grove provides a number of
`Cookiecutter`_ templates.

Please see the `Grove Code Templates`_ section of the Grove repository for more about
these templates, and how to use them.
